summaryrefslogtreecommitdiffstats
path: root/chrome/browser/gtk/infobar_container_gtk.h
diff options
context:
space:
mode:
authorestade@chromium.org <estade@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-08-31 18:31:05 +0000
committerestade@chromium.org <estade@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-08-31 18:31:05 +0000
commit62391376b5c86eea70af0d8e429ffc8a4b56e60d (patch)
treee5382e8663a693fc0f78040310e403f46ecaa7b2 /chrome/browser/gtk/infobar_container_gtk.h
parent2951965787cea2ad2f1c966791a68e2f10874071 (diff)
downloadchromium_src-62391376b5c86eea70af0d8e429ffc8a4b56e60d.zip
chromium_src-62391376b5c86eea70af0d8e429ffc8a4b56e60d.tar.gz
chromium_src-62391376b5c86eea70af0d8e429ffc8a4b56e60d.tar.bz2
Don't resize the renderer while opening the bookmark bar or an infobar.
This is just a performance optimization. Previously this code was added for closing bookmark bars as a bit of visual polish.Doing the same thing for opening bookmark bars should reduce CPU usage but it won't look any different (for fast computers anyway). BUG=17133 Review URL: http://codereview.chromium.org/183011 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@24911 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/gtk/infobar_container_gtk.h')
-rw-r--r--chrome/browser/gtk/infobar_container_gtk.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/chrome/browser/gtk/infobar_container_gtk.h b/chrome/browser/gtk/infobar_container_gtk.h
index e620b2e..e8a3c7c 100644
--- a/chrome/browser/gtk/infobar_container_gtk.h
+++ b/chrome/browser/gtk/infobar_container_gtk.h
@@ -34,8 +34,8 @@ class InfoBarContainerGtk : public NotificationObserver {
void RemoveDelegate(InfoBarDelegate* delegate);
// Returns the total pixel height of all infobars in this container that
- // are currently closing.
- int TotalHeightOfClosingBars() const;
+ // are currently animating.
+ int TotalHeightOfAnimatingBars() const;
private:
// Overridden from NotificationObserver: